;
;****************************************
;*    CMS-8GP32 Board Test Program:     *
;*             AXMAN                    *
;*                                      *
;*     Flash Rom version                *
;****************************************

            XDEF IRQ
            XDEF Entry

initStack:  EQU    $023F   ; stack default is $23F.

; Register equates...

PTA:            Equ     $00     ; Port A Data Register
PTB:            Equ     $01     ; Port B Data Register
PTC:            Equ     $02     ; Port C Data Register
PTD:            Equ     $03     ; Port D Data Register
DDRA:           Equ     $04     ; Port A data direction
DDRB:           Equ     $05     ; Port B data direction
DDRC:           Equ     $06     ; Port C data direction
DDRD:           Equ     $07     ; Port D data direction
PTE:            Equ     $08     ; Port E data register
DDRE:           Equ     $0C     ; Port E data direction
PTAPUE:         Equ     $0D     ; Port A input Pullup
PTCPUE:         Equ     $0E     ; Port C input pullup
PTDPUE:         Equ     $0F     ; Port D input pullup 
SCC1:		EQU	$13	; SCI register definitions...
SCC2:		EQU	$14	;
SCC3:		EQU	$15	;
SCBR:		EQU	$19	;
SCS1:		EQU	$16	;
SCS2:		EQU	$17	;
SCDR:		EQU	$18	;
TBCR:       Equ     $1C     ; timebase control register
CONFIG1:	EQU	$1F	; config register
CONFIG2:	EQU	$1E	;
T1SC:           Equ     $20     ; timer 1 status & control
T1CNTH:         Equ     $21     ; timer 1 counter register High
T1CNTL:         Equ     $22     ; timer 1 counter register low
T1MODH:         Equ     $23     ; timer 1 counter Modulo high
T1MODL:         Equ     $24     ; timer 1 counter Modulo Low
T1SC0:          Equ     $25     ; timer 1 channel 0 status
T1CH0H:         Equ     $26     ; timer 1 channel 0 high
T1CH0L:         Equ     $27     ; timer 1 channel 0 Low
T1SC1:          Equ     $28     ; timer 1 channel 1 status
T1CH1H:         Equ     $29     ; timer 1 channel 1 high
T1CH1L:         Equ     $2A     ; timer 1 channel 1 low
T2SC:           Equ     $2B     ; timer 2 status & control
T2CNTH:         Equ     $2C     ; timer 2 counter register
T2CNTL:         Equ     $2D     ; timer 2 counter register
T2MODH:         Equ     $2E     ; timer 2 counter Modulo
T2MODL:         Equ     $2F     ; timer 2 counter Modulo
T2SC0:          Equ     $30     ; timer 2 channel 0 status
T2CH0H:         Equ     $31     ; timer 2 channel 0 high
T2CH0L:         Equ     $32     ; timer 2 channel 0 Low
T2SC1:          Equ     $33     ; timer 2 channel 1 status
T2CH1H:         Equ     $34     ; timer 2 channel 1 high
T2CH1L:         Equ     $35     ; timer 2 channel 1 low
PCTL:           Equ     $36     ; 
PBWC:           equ     $37     ;
PMSH:           equ     $38     ;
PMSL:           equ     $39     ;
PMRS:           equ     $3A     ;
SBSR:           Equ     $FE00   ; Sim Break Status Register
SRSR:           Equ     $FE01   ; Sim reset status register
SUBAR:          Equ     $FE02   ; Sim upper byte address
SBFCR:          Equ     $FE03   ; Sim break flag control
INT1:           Equ     $FE04   ; interrupt status register 1
INT2:           Equ     $FE05   ; interrupt status register 2
INT3:           Equ     $FE06   ; interrupt status register 3

; data equates....

CR:		EQU	$0d		; hex carriage return character
LF:		EQU	$0A		; hex line feed character
NUL:		EQU	$00		; ascii null character, end of string
PLLON:      equ   5           ; PLL bit
LOCK:       equ   6
BCS:        equ   4
AUTO:       equ   7

; Interrupt vectors
IRQ:            equ     $fe27           ; Irq interrupt vector


;MyStack:	SECTION	; stack default area = $200 - 23F.


; Data space for direct addressing mode...
;MyData1:     SECTION SHORT
            org  $40
Tmp:		DS.B	1	; temp use register
Tmp1:		DS.B	1	; temp use register
counter:    DS.B  1	; temp use counter

; Data space for extended addressing modes..
;MyData2:	SECTION

Tmpl:		DS.B	1	; temp use register

; Start rom space ...
;MyCode:     SECTION
            org  $8000
; constants and text strings here...



MENU:	
        DC      CR
        DC      LF
        DC      CR
        DC      LF
        DC      CR
        DC      LF
        DC	"AXIOM MFG. CMS-08GP32 UTILITIES   1.1"
        DC      CR
	  DC      LF
        DC      "Press key 1 or 2"
        DC      CR
        DC      LF  
        DC      "1. Serial Port Test      2. I/O Port Test"
        DC      CR
        DC      LF
        DC      CR
	DC	NUL             ; end of message
MSG_ECHO:
        DC      CR
        DC      LF
        DC      CR
        DC      LF
        DC      "Press any key to echo, press space bar to quit"
        DC      CR
        DC      LF
        DC      NUL
           
MSG_TST:
        DC      CR
        DC      LF
        DC      CR
        DC      LF
        DC      "Ports A,B,C,D are toggling, press any key to quit"
        DC      NUL        
; Start program here...
Entry:
	LDHX   #initStack   ; initialize Stack
      TXS
	LDA	#$4B		; Set configuration registers
	STA	CONFIG1	; Stop on, COP off, LVI = 5V
	LDA	#$01		; 
	STA	CONFIG2	; SCI Baud = I clk (2.4576Mhz)
;	LDA	#$02		; configure serial port, 9600, 8, n, 1
;	STA	SCBR
      jsr   H08PLL      ; set up PLL & baud rate for 8mhz & 9600

	LDA	#$44
	STA	SCC1
	LDA	#$0C
	STA	SCC2
	CLR	SCC3
        CLI
	
	nop
Main:
        LDHX	#MENU   	; Point to Menu
        JSR	Send_MSG	; send main menu string
        
	JSR	INPUT   	; Get menu choice
	JSR	OUTPUT	; echo choice
        cmp     #$31            ; choice = 1?
        bne     NEXT01
; echo characters , quit if space bar is pressed
        LDHX    #MSG_ECHO       ; load ehco test message
        jsr     Send_MSG        ; send message
ECHOL01:
        jsr     INPUT           ; read a character
        cmp     #$20            ; space?
        beq     Main            ; return to main menu
        cmp     #$0d            ; car ret?
        bne     ECHON01
        lda     #$0a            ; send line feed
ECHON01:
        jsr     OUTPUT          ; echo char
        bra     ECHOL01         ; repeat


NEXT01:
        cmp     #$32            ; choice = 2?
        bne     Main            ; invalid choice
        LDHX    #MSG_TST        ; Port test message
        jsr     Send_MSG        ; 


; Setup Ports




        clr     DDRA            ; Port A all inputs
        clr     DDRB            ; Port B all inputs
        clr     DDRC            ; Port C all inputs
        clr     DDRD            ; Port D all inputs 

        
        lda     #$ff            ; set Pull Ups
        sta     PTAPUE          ; enable port a pull ups
        sta     PTCPUE          ; enable port c pull ups
        sta     PTDPUE          ; enable port d pull ups
        ldhx    #$0000          ; delay value
PORTTL2:
        incx                    ; wait for ports to pull-up
        bne     PORTTL2
        lda     PTA             ; read port A
        cmp     #$ff            ; all pins should be high
        bne     Main
        lda     PTC             ; read port c
        and     #$7f
        cmp     #$7f            ; all pins should be high
        bne     Main 
PORTLP:
        jsr     PORTTST         ; do a port test
        jsr     Receive         ; read a character
        bcc     PORTLP          ; no char received, repeat 
        lda     #$00           
        sta     DDRA            ; Port A all inputs
        sta     DDRB            ; Port B all inputs
        sta     DDRC            ; Port C all inputs
        sta     DDRD            ; Port D all inputs 
	bra     Main
        


; Input a character from input device
INPUT:  jsr     Receive         ; poll for char
        bcc     INPUT           ; repeat until char is received
        rts
; Poll receiver for any data in...
Receive:
	LDA	SCS1		; read status
	BIT	#$20		; test if receive rdy
	BNE	Receive1	; if true, get byte
	CLC			; clear recv flag
	RTS
Receive1:
	LDA	SCDR		; READ byte
	SEC			; set recv flag
	RTS


; OUTPUT a byte....
OUTPUT:
	PSHA			; Temp Save byte
OUTPUT1:
	LDA	SCS1		; read status
	BPL	OUTPUT1	; loop for ready to send
	PULA			; get data back
	STA	SCDR		; send byte
	RTS

; OUTPUT hello string...
Send_MSG:
	
Send_lp:
	LDA	,X		; get byte
	INCX			; bump pointer +1
	JSR	OUTPUT	; send byte out
	CMP	#NUL		; test for end 
	BNE	Send_lp   	; loop if more bytes
	RTS
;     

     
;
; Ports Test
PORTTST:
          lda     #$ff           
          sta     DDRA            ; Port A all outputs
          sta     DDRB            ; Port B all Outputs
          sta     DDRC            ; Port C all outputs
          sta     DDRD            ; Port D all outputs 
          clra                    ; clear acc a
PORTTL1:
          sta     PTA             ; store in Port A
          sta     PTB             ; store in Port B
          sta     PTC             ; store in Port C
          sta     PTD             ; store in Port D
          inca                    ; increment acc A
          bne     PORTTL1         ; repeat until done     
          rts     
;
;
; clock pll set up
H08PLL:
          ldhx    #CLK8MHZ        ; point to table
          bclr    BCS,PCTL        ; select external reference
          bclr    PLLON,PCTL      ; turn off PLL
          mov     x+,PCTL         ; prog P & E
          mov     x+,PMRS         ; prog L
          mov     x+,PMSH         ; prog N msb
          mov     x+,PMSL         ; prog N lsb
          mov     x+,SCBR         ; set baud
          bset    AUTO,PBWC       ; bandwidth
          bset    PLLON,PCTL      ; PLL on
PLLwait:
          brclr   LOCK,PBWC,PLLwait ; lock PLL
          bset    BCS,PCTL          ; VCO select     
          rts               
;
; table PLL for 8.003584 Mhz
CLK8MHZ:          
          dc.b    $02             ; P & E
          dc.b    $d0             ; L
          dc.b    $03             ; N msb
          dc.b    $d1             ; N lsb
          dc.b    $30             ; 9600 baud
;
;
; Hex Input routines
;
; convert acc a to a hex value
HEXCON:
          sub     #$30            ; remove base number
          cmp     #$0a            ; if 0-9 then end
          blo     HEXI01 
          sub     #$07            ; convert A - F
          and     #$0f            ; remove upper case
HEXI01:
          rts
;
;
; Hex Output Routines
;
; Output right four bits of acc A as a hex ascii value
; send to com port
HEXOUT:
          and    #$0f            ; mask off bits
          cmp    #$09            ; number?
          bhi    HEXOUT01           ; a - f?
          add    #$30            ; add offset
          jsr    OUTPUT          ; send to output
          rts
HEXOUT01:
          add    #$37            ; a - f to ascii
          jsr    OUTPUT
          rts          
;
;          

; set reset vector
         org     $fffe 
         DC.W    Entry

         END            



